==> cfn_lint-0.79.1-py3-none-any.whl: cfnlint/template/transforms/transform.py <==
"""
Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: MIT-0
"""
from __future__ import annotations

from typing import Any, Mapping

from cfnlint.conditions import Conditions
from cfnlint.graph import Graph
from cfnlint.template.transforms._language_extensions import language_extension
from cfnlint.template.transforms._protocols import Transformer
from cfnlint.template.transforms._sam import sam


class Transform:
    def __init__(self) -> None:
        self.transforms: Mapping[str, Transformer] = {
            "AWS::Serverless-2016-10-31": sam,
            "AWS::LanguageExtensions": language_extension,
        }

    def transform(self, cfn: Any):
        """Transform logic"""
        matches = []
        transform_declaration = cfn.template.get("Transform", [])
        transform_type = (
            transform_declaration
            if isinstance(transform_declaration, list)
            else [transform_declaration]
        )

        if not transform_type:
            return matches

        cfn.transform_pre["Globals"] = cfn.template.get("Globals", {})
        for name in transform_type:
            if not isinstance(name, str):
                continue
            transform = self.transforms.get(name)
            if not transform:
                continue

            matches, template = transform(cfn)
            if matches:
                return matches
            cfn.template = template

        cfn.graph = Graph(cfn)
        cfn.conditions = Conditions(cfn)
        return matches

==> cfn_lint-1.2.4a1-py3-none-any.whl: cfnlint/template/transforms/transform.py <==
"""
Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
SPDX-License-Identifier: MIT-0
"""

from __future__ import annotations

import logging
from typing import Any, Callable, List, Mapping

from cfnlint.conditions import Conditions
from cfnlint.context import ContextManager
from cfnlint.graph import Graph
from cfnlint.match import Match
from cfnlint.template.transforms._language_extensions import language_extension
from cfnlint.template.transforms._sam import sam
from cfnlint.template.transforms._types import TransformResult

LOGGER = logging.getLogger("cfnlint")


class Transform:
    def __init__(self) -> None:
        self.transforms: Mapping[str, Callable[[Any], TransformResult]] = {
            "AWS::Serverless-2016-10-31": sam,
            "AWS::LanguageExtensions": language_extension,
        }

    def transform(self, cfn: Any) -> List[Match]:
        """Transform logic"""
        matches: List[Match] = []
        transform_declaration = cfn.template.get("Transform", [])
        transform_type = (
            transform_declaration
            if isinstance(transform_declaration, list)
            else [transform_declaration]
        )

        if not transform_type:
            return matches

        cfn.transform_pre["Globals"] = cfn.template.get("Globals", {})
        for name in transform_type:
            if not isinstance(name, str):
                continue
            transform = self.transforms.get(name)
            if not transform:
                continue

            matches, template = transform(cfn)
            if matches:
                return matches
            cfn.template = template

        LOGGER.info("Transformed template: %s", cfn.template)
        cfn.graph = Graph(cfn)
        cfn.conditions = Conditions(cfn)
        cfn.context = ContextManager(cfn)
        LOGGER.info("Transformed template: %s", cfn.template)
        return matches
